@@ -791,7 +791,6 @@ class CloudvectorDAST(object):
         def get_metadata_for_fuzzinput(in_file):
             for type, subtype in attack_info.items():
                 for name, info in subtype.items():
-                    #print(name, info.get("file_set"), in_file, "\n\n\n")
                     if str(in_file).lower() in [str(_).replace("\\","/").split("/")[-1].lower() for _ in info.get("file_set",[])]:
                         return info
             return None
@@ -816,26 +815,31 @@ class CloudvectorDAST(object):
             except:
                 response_code = 0
             try:
-                fuzz_sub_type = metadata.split("::")[3].replace("\\","/").split("/")[-1]
+                fuzz_sub_type = metadata.split("::")[6]
             except:
                 fuzz_sub_type = "na"
             try:
-                fuzz_type = metadata.split("::")[3].replace(fuzz_sub_type,"").replace("\\","/").replace("attack","").replace("//","/").split("/")[1]
+                fuzz_file = metadata.split("::")[6].split("/")[-1]
+            except:
+                fuzz_file = "na"
+            try:
+                fuzz_type = metadata.split("::")[3]
             except:
                 fuzz_type = "na"
             try:
-                test_response = metadata.split("::")[4]
+                test_response = metadata.split("::")[4].split("<body>")[-1]
             except:
                 test_response = None
             try:
-                if "CURL command to retry:" in curl_command_to_try:
-                    curl_command_to_try = stdout.split("CURL command to retry:")[-1].split("---------------------------------")[0].replace("\n","")
+                if "CURL command to retry:" in stdout:
+                    curl_command_to_try = stdout.split("CURL command to retry:")[-1].replace("\n","").split("-------------------------------------------------------")[0]
                 else:
                     curl_command_to_try = ""
             except:
                 curl_command_to_try = ""
 
-            #print(curl_command_to_try,"\n\n\n", stdout)
+            if str(fuzz_type).lower() in ["na","all"]:
+                continue
 
             if api_name not in consolidated_report:
                 consolidated_report[api_name] = {}
@@ -856,9 +860,7 @@ class CloudvectorDAST(object):
                 consolidated_report[api_name][api_method][fuzz_type]["resp_length"].append(response_length)
                 consolidated_report[api_name][api_method][fuzz_type]["resp_code"].append(response_code)
 
-            fuzz_metadata = get_metadata_for_fuzzinput(fuzz_sub_type)
-
-
+            fuzz_metadata = get_metadata_for_fuzzinput(fuzz_file)
 
             if fuzz_metadata:
                 fuzz_metainfo[fuzz_type] = {
@@ -871,7 +873,7 @@ class CloudvectorDAST(object):
                         "ease_of_exploitation": fuzz_metadata.get("ease_of_exploitation")
                     }
 
-            if str(test["outcome"]).lower() == "failed":
+            if str(test["outcome"]).lower() in ["failed", "passed"]:
                 if not fuzz_metadata:
                     continue
                 fuzz_severity = str(fuzz_metadata.get("severity")).lower()
@@ -896,7 +898,8 @@ class CloudvectorDAST(object):
                                                 "api": api_name,
                                                 "api_method": api_method,
                                                 "api_response": test_response,
-                                                "req_curl": curl_command_to_try
+                                                "req_curl": curl_command_to_try,
+                                                "status": str(test["outcome"]).lower()
                                           }]
                         }
                 else:
@@ -904,10 +907,10 @@ class CloudvectorDAST(object):
                                                 "api": api_name,
                                                 "api_method": api_method,
                                                 "api_response": test_response,
-                                                "req_curl": curl_command_to_try
+                                                "req_curl": curl_command_to_try,
+                                                "status": str(test["outcome"]).lower()
                                           })
 
-
         api_data = []
         vulnerabilities_found = 0
         total_api_calls = 0
@@ -926,7 +929,6 @@ class CloudvectorDAST(object):
                     resp_code += info["resp_code"]
                     resp_duration += info["resp_duration"]
                     resp_length += info["resp_length"]
-
                 vulnerabilities_found += failed_tests
                 record = {"name": api.replace("9i9","-"), "method": method, "resp_duration": resp_duration,
                           "spec": "openapi_spec.json", "total_tests": total_tests,
@@ -1022,7 +1024,7 @@ class CloudvectorDAST(object):
 
         for severity, types in fuzz_types.items():
             for k, v in types.items():
-                vulns_stats[severity] = len(v.get("executions",[]))
+                vulns_stats[severity] += len([_ for _ in v.get("executions") if _.get("status")=="failed"])
 
         with open(output_report, "wb+") as file_:
             file_.write(template.render(api_data=api_data, fuzz_data=fuzz_data_processed, total_api_calls=total_api_calls,
@@ -1031,7 +1033,7 @@ class CloudvectorDAST(object):
                                         fuzz_types=fuzz_types, vulns_stats=vulns_stats, fuzz_metadata=fuzz_metainfo,
                                         detailed_report=os.path.join(os.getcwd(),"CVIAST-detailed_report.html"),
                                         test_lapse_time=str(round(int(report["report"]["summary"]["duration"])/60))+" min(s)").encode("utf-8","ignore"))
-        print("CVIAST report saved in " + os.path.join(os.getcwd(),output_report)+"\n\n")
+        print("\n\tCVIAST report saved in " + os.path.join(os.getcwd(),output_report)+"\n\n")
 
 
     @staticmethod
@@ -1139,7 +1141,8 @@ class CloudvectorDAST(object):
             with open("tests/data/params_info_from_spec.json") as fobj:
                 f1 = json.load(fobj)
         except FileNotFoundError:
-            print("Error: You need to have used a valid SPEC to generate the tests to know the parameter details")
+            print("Error: You need to have used a valid SPEC to generate the tests to know the parameter details, Please regenerate tests!!!")
+            return
         input_params = {}
         for api, info in f1.items():
             if api not in input_params:
@@ -1199,7 +1202,7 @@ def printProgressBar (iteration, total, prefix = '', suffix = '', decimals = 1,
     percent = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
     filledLength = int(length * iteration // total)
     bar = fill * filledLength + '-' * (length - filledLength)
-    print(f'\r{prefix} |{bar}| {percent}% {suffix}', end = printEnd)
+    print('\r{prefix} |{bar}| {percent}% {suffix}'.format(prefix=prefix, bar=bar, percent=percent, suffix=suffix), end = printEnd)
     # Print New Line on Complete
     if iteration == total:
         print()
@@ -1218,11 +1221,15 @@ def main():
     #
     # args = parser.parse_args()
     html_report_name = "CVIAST-report.html"
+    quiet_mode = True
     if sys.argv[1:]:
         for _ in sys.argv[1:]:
             if "report-out" in _:
                 html_report_name = _.split("=")[-1]
                 sys.argv.remove(_)
+            if "--v" in _:
+                quiet_mode = False
+                sys.argv.remove(_)
         if sys.argv[1:][0] == "--list-supported-fuzz-types":
             print("\n\t\t\t\t\t\t".join(supoorted_fuzz_types))
             return
@@ -1234,23 +1241,27 @@ def main():
             return
         if sys.argv[1:][0] == "--execute":
             arguments = sys.argv[2:]
-            arguments += ["--json=report.json", "--html=CVIAST-detailed_report.html", "--self-contained-html", "-vv"]
-            #arguments += ["--json=report.json", "--html=CVIAST-detailed_report.html", "--self-contained-html", "-vv", ">> cviast_execution_log.txt"]
+            if not quiet_mode:
+                arguments += ["--json=report.json", "--html=CVIAST-detailed_report.html", "--self-contained-html", "-vv"]
+            else:
+                arguments += ["--json=report.json", "--html=CVIAST-detailed_report.html", "--self-contained-html", "-vv", ">> cviast_execution_log.txt"]
             try:
                 print("\n....Test Execution is in progress.............\n\n")
-                pytest.main(arguments)
-                #os.system("pytest "+" ".join(arguments))
+                if not quiet_mode:
+                    pytest.main(arguments)
+                else:
+                    os.system("pytest "+" ".join(arguments))
                 CloudvectorDAST.generate_fuzz_report(html_report_name)
             except:
                 pass
             return
 
-    print(sys.argv)
     if os.path.exists(os.path.join(os.getcwd(), "my_cesetup.yaml")):
         with open(os.path.join(os.getcwd(), "my_cesetup.yaml")) as fobj:
             ce_details = yaml.load(fobj, Loader=yaml.FullLoader)
     else:
         ce_details = {}
+
     print("\n\n")
     print("\t" * 7 + "# /***************************************************************\\")
     print("\t" * 7 + "# **                                                           **")
